using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.IO;
using System.Windows.Forms;
using System.Collections.Specialized;
using GrapeCity.ActiveReports;
using GrapeCity.ActiveReports.Rendering.IO;
using GrapeCity.ActiveReports.Document;
using GrapeCity.ActiveReports.Export.Html.Page;
using GrapeCity.ActiveReports.Export.Image.Page;
using GrapeCity.ActiveReports.Export.Pdf.Page;
using GrapeCity.ActiveReports.Export.Rdf;
using GrapeCity.ActiveReports.Export.Word.Page;
using GrapeCity.ActiveReports.Export.Excel.Page;
using GrapeCity.ActiveReports.Export.Xaml.DDR;
using GrapeCity.ActiveReports.Export.Xml.Page;
namespace GrapeCity.ActiveReports.Samples.EndUserDesigner
{
    public partial class PageReportExportProperties : Form
    {
        /// <summary>
        ///Exports the PageReport designed in the Designer 
        /// </summary>   
        object _exportsettings = null;
        string _filter = "";
        private PageDocument _document;
        FileStreamProvider _exportfile;
        public PageReportExportProperties(MemoryStream reporttobeexported)
        {
            InitializeComponent();
            _document = new PageDocument(new PageReport(new StreamReader(reporttobeexported)));
        }
        private void PageReportExportProperties_Load(object sender, EventArgs e)
        {
        }
        private void browsebutton_Click(object sender, EventArgs e)
        {
            /// <summary>
            ///Sets the Exported Report File
            /// </summary>   
            using (SaveFileDialog _save = new SaveFileDialog())
            {
                _save.Filter = _filter;
                _save.InitialDirectory = Path.GetDirectoryName(Application.StartupPath);
                _save.RestoreDirectory = true;
                if (_save.ShowDialog() == DialogResult.OK)
                {
                    this.exportbutton.Enabled = true;
                    this.resetbutton.Enabled = true;
                    this.exportfiletextBox.Text = _save.FileName;
                    this.exporttypecomboBox.Enabled = false;
                    this.browsebutton.Enabled = false;
                    _exportfile = new FileStreamProvider(new DirectoryInfo(Path.GetDirectoryName(_save.FileName)), Path.GetFileNameWithoutExtension(_save.FileName));
                }
            }
        }
        private void exportbutton_Click(object sender, EventArgs e)
        {
            /// <summary>
            ///Sets the properties of the rendering extension to which the report is to be rendered from the propertygrid
            /// </summary>   
            NameValueCollection _settings = new NameValueCollection();
            PropertyDescriptorCollection col = this.exportpropertyGrid.SelectedTab.GetProperties(_exportsettings);
            foreach (PropertyDescriptor pd in col)
            {
                if (pd.GetValue(_exportsettings) != null)
                    _settings.Add(pd.Name, pd.GetValue(_exportsettings).ToString());
            }
            /// <summary>
            ///Rendering to various formats
            /// </summary>
            switch (this.exporttypecomboBox.SelectedItem.ToString())
            {
                case "Excel":
                    {
                        ExcelTransformationDevice _excel = new ExcelTransformationDevice();
                        _document.Render(_excel, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
                case "Html":
                    {
                        HtmlRenderingExtension _html = new HtmlRenderingExtension();
                        _document.Render(_html, _exportfile, _settings);
                        _html.Dispose();
                        _document.Dispose();
                        break;
                    }
                case "Image":
                    {
                        ImageRenderingExtension _img = new ImageRenderingExtension();
                        _document.Render(_img, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
                case "Pdf":
                    {
                        PdfRenderingExtension _pdf = new PdfRenderingExtension();
                        _document.Render(_pdf, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
                case "Rdf":
                    {
                        RdfRenderingExtension _rdf = new RdfRenderingExtension();
                        _document.Render(_rdf, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
                case "Word":
                    {
                        WordRenderingExtension _word = new WordRenderingExtension();
                        _document.Render(_word, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
                case "Xaml":
                    {
                        XamlRenderingExtension _xaml = new XamlRenderingExtension();
                        _document.Render(_xaml, _exportfile, _settings);
                        _xaml.Dispose();
                        _document.Dispose();
                        break;
                    }
                case "Xml":
                    {
                        XmlRenderingExtension _xml = new XmlRenderingExtension();
                        _document.Render(_xml, _exportfile, _settings);
                        _document.Dispose();
                        break;
                    }
            }
            this.Close();
        }
        private void exporttypecomboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.resetbutton.Enabled = false;
            switch (this.exporttypecomboBox.SelectedItem.ToString())
            {
                case "Excel":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Excel.Page.Settings();
                        this.exportpropertyGrid.SelectedObject = _exportsettings;
                        _filter = "excel files (*.xls)|*.xls|All files (*.*)|*.*";
                        break;
                    }
                case "Html":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Html.Page.Settings();
                        _filter = "html files (*.htm)|*.html|All files (*.*)|*.*";
                        break;
                    }
                case "Image":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Image.Page.Settings();
                        _filter = "image files(*.BMP;*.EMF;*.GIF;*.JPEG;*.TIFF;*.PNG)|*.BMP;*.EMF;*.GIF;*.JPEG;*.TIFF;*.PNG";
                        break;
                    }
                case "Pdf":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Pdf.Page.Settings();
                        _filter = "pdf files (*.pdf)|*.pdf|All files (*.*)|*.*";
                        break;
                    }
                case "Rdf":
                    {
                        this.exportpropertyGrid.Visible = false;
                        _filter = "rdf files (*.rdf)|*.rdf|All files (*.*)|*.*";
                        break;
                    }
                case "Word":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Word.Page.Settings();
                        _filter = "word files (*.doc)|*.doc|All files (*.*)|*.*";
                        break;
                    }
                case "Xaml":
                    {
                        this.exportpropertyGrid.Visible = false;
                        _filter = "xaml files (*.xaml)|*.xaml|All files (*.*)|*.*";
                        break;
                    }
                case "Xml":
                    {
                        this.exportpropertyGrid.Visible = true;
                        _exportsettings = new GrapeCity.ActiveReports.Export.Xml.Page.Settings();
                        _filter = "xml files (*.xml)|*.xml|All files (*.*)|*.*";
                        break;
                    }
            }
            this.exportpropertyGrid.SelectedObject = _exportsettings;
        }
        private void resetbutton_Click(object sender, EventArgs e)
        {
            this.browsebutton.Enabled = true;
            this.exportbutton.Enabled = false;
            this.exporttypecomboBox.Enabled = true;
            this.exportfiletextBox.Text = "";
        }
    }
}
